"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createCrashDetails = exports.DefectTrackerType = exports.ProcessingStatus = void 0;
var _crash_1 = require("../index");
var argument_contracts_1 = __importDefault(require("argument-contracts"));
var event_1 = require("../../events/events-api-client/event");
var ProcessingStatus;
(function (ProcessingStatus) {
    ProcessingStatus[ProcessingStatus["Processing"] = 0] = "Processing";
    ProcessingStatus[ProcessingStatus["ActiveThreadComplete"] = 1] = "ActiveThreadComplete";
    ProcessingStatus[ProcessingStatus["Complete"] = 2] = "Complete";
})(ProcessingStatus = exports.ProcessingStatus || (exports.ProcessingStatus = {}));
var DefectTrackerType;
(function (DefectTrackerType) {
    DefectTrackerType["None"] = "None";
    DefectTrackerType["FogBugz"] = "FogBugz";
    DefectTrackerType["Jira"] = "Jira";
    DefectTrackerType["Azure"] = "Azure DevOps";
    DefectTrackerType["YouTrack"] = "YouTrack";
    DefectTrackerType["GitHub"] = "GitHub";
    DefectTrackerType["Assembla"] = "Assembla";
})(DefectTrackerType = exports.DefectTrackerType || (exports.DefectTrackerType = {}));
function createCrashDetails(options) {
    argument_contracts_1.default.assertNumber(options.processed, 'options.processed');
    argument_contracts_1.default.assertNumber(options.id, 'options.id');
    argument_contracts_1.default.assertNumber(options.stackKeyId, 'options.stackKeyId');
    argument_contracts_1.default.assertBoolean(options.missingSymbols, 'options.missingSymbols');
    var appName = defaultToEmptyString(options.appName, 'options.appName');
    var appVersion = defaultToEmptyString(options.appVersion, 'options.appVersion');
    var appKey = defaultToEmptyString(options.appKey, 'options.appKey');
    var comments = defaultToEmptyString(options.comments, 'options.comments');
    var crashTime = defaultToEmptyString(options.crashTime, 'options.crashTime');
    var defectLabel = defaultToEmptyString(options.defectLabel, 'options.defectLabel');
    var defectUrl = defaultToEmptyString(options.defectUrl, 'options.defectUrl');
    var description = defaultToEmptyString(options.description, 'options.description');
    var dumpfile = defaultToEmptyString(options.dumpfile, 'options.dumpfile');
    var email = defaultToEmptyString(options.email, 'options.email');
    var exceptionCode = defaultToEmptyString(options.exceptionCode, 'options.exceptionCode');
    var exceptionMessage = defaultToEmptyString(options.exceptionMessage, 'options.exceptionMessage');
    var ipAddress = defaultToEmptyString(options.ipAddress, 'options.ipAddress');
    var platform = defaultToEmptyString(options.platform, 'options.platform');
    var processor = defaultToEmptyString(options.processor, 'options.processor');
    var stackKeyComment = defaultToEmptyString(options.stackKeyComment, 'options.stackKeyComment');
    var stackKeyDefectLabel = defaultToEmptyString(options.stackKeyDefectLabel, 'options.stackKeyDefectLabel');
    var stackKeyDefectUrl = defaultToEmptyString(options.stackKeyDefectUrl, 'options.stackKeyDefectUrl');
    var user = defaultToEmptyString(options.user, 'options.user');
    argument_contracts_1.default.assertType(options.thread, _crash_1.ThreadCollection, 'options.thread');
    argument_contracts_1.default.assertType(options.additionalFiles, Array, 'options.additionalFiles');
    argument_contracts_1.default.assertType(options.events, Array, 'options.events');
    var events = (0, event_1.createEvents)(options.events);
    var thread = new _crash_1.GroupableThreadCollection(__assign(__assign({}, options.thread), { stackKeyId: options.stackKeyId }));
    var additionalInfo = _crash_1.AdditionalInfo.fromRawResponse(options.debuggerOutput);
    return __assign(__assign({}, options), { appKey: appKey, appName: appName, appVersion: appVersion, comments: comments, crashTime: crashTime, defectLabel: defectLabel, defectUrl: defectUrl, description: description, dumpfile: dumpfile, email: email, exceptionCode: exceptionCode, exceptionMessage: exceptionMessage, ipAddress: ipAddress, platform: platform, processor: processor, stackKeyComment: stackKeyComment, stackKeyDefectLabel: stackKeyDefectLabel, stackKeyDefectUrl: stackKeyDefectUrl, user: user, thread: thread, additionalInfo: additionalInfo, events: events });
}
exports.createCrashDetails = createCrashDetails;
function defaultToEmptyString(value, name) {
    if (value) {
        argument_contracts_1.default.assertString(value, name);
        return value;
    }
    else {
        return '';
    }
}
//# sourceMappingURL=crash-details.js.map